@@ -1,5 +1,15 @@
 "cohen.d" <- function(x,group,alpha=.05,std=TRUE,sort=NULL,dictionary=NULL,MD=TRUE) {
 cl <- match.call()
+group2 <- NULL
+if(inherits(x,"formula")) {ps <- fparse(x)   #group was specified, call describeBy
+	x <- get(ps$y)
+	group <- ps$x 
+	if(length(group ) > 1) {group2 <- group[2]
+	 group <- group[1]}
+	 }
+	 
+	if(!is.null(group2)){cohen.d.by(x =x, group=group,group2=group2)} else {
+	
 if ((length(group) ==1) && ( group %in% colnames(x) )) {group <- which(colnames(x) %in% group)
   group.in <- TRUE} else {group.in <- FALSE}
  stats <- statsBy(x,group)
@@ -43,6 +53,7 @@ result <- list(cohen.d = cohen.d.conf,hedges.g = hedges.g, M.dist = D, r=r,t=t,n
 class(result) <- c("psych","cohen.d")
 return(result)
 }
+}
 
 "d2t" <- function(d,n=NULL,n2=NULL,n1=NULL) {if(is.null(n1)) {t <- d*sqrt(n)/2} else 
     if(is.null(n2)) {t <- d*sqrt(n1) } else {
@@ -95,6 +106,11 @@ invisible(result) #return the values as well
  
  "cohen.d.by" <- 
 function(x,group,group2,alpha=.05,MD=TRUE)  {
+if(inherits(x,"formula")) {ps <- fparse(x)   #group was specified, call describeBy
+	x <- get(ps$y)
+	group <- ps$x 
+	if(length(group ) > 1) {group2 <- group[2]
+	 group <- group[1]}}
 
 
   group1 <- group
