@@ -5,18 +5,20 @@
 function (x,group=NULL,mat=FALSE,type=3,...) {               #data are x, grouping variable is group
 .Deprecated("describeBy", msg = "describe.by is deprecated.  Please use the describeBy function")
   if(inherits(x,"formula")) {ps <- fparse(x) 
-    x <- get(ps$y)
+    x <- ps$y
 group <- ps$x} 
 answer <- describeBy(x=x,group=group,mat=mat,type=type,...)
 return(answer)}
 
 #July 9, 2020  added the ability to do formula input
 "describeBy" <-
-function (x,group=NULL,mat=FALSE,type=3,digits=15,...) {               #data are x, grouping variable is group
+function (x,group=NULL,mat=FALSE,type=3,digits=15,data=NULL,...) {               #data are x, grouping variable is group
    cl <- match.call()
    if(inherits(x,"formula")) {ps <- fparse(x) 
-    x <- get(ps$y)
-group <- ps$x} 
+   if(missing(data)) {x <- get(ps$y)
+   group <- x[ps$x]} else {x <- data[ps$y]
+   group <- data[ps$x]}
+} 
  if(is.null(group)) {answer <- describe(x,type=type)
    warning("no grouping variable requested")} else {
    if(!is.data.frame(group) && !is.list(group) && (length(group) < NROW(x))) group <- x[,group]
